==> cxf-services-xkms-common-3.3.10-sources.jar: org/apache/cxf/xkms/model/xkms/KeyBindingEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for KeyBindingEnum.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * &lt;pre&gt;
 * &amp;lt;simpleType name="KeyBindingEnum"&amp;gt;
 *   &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Valid"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Invalid"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Indeterminate"/&amp;gt;
 *   &amp;lt;/restriction&amp;gt;
 * &amp;lt;/simpleType&amp;gt;
 * &lt;/pre&gt;
 * 
 */
@XmlType(name = "KeyBindingEnum")
@XmlEnum
public enum KeyBindingEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Valid")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_VALID("http://www.w3.org/2002/03/xkms#Valid"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Invalid")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INVALID("http://www.w3.org/2002/03/xkms#Invalid"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Indeterminate")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INDETERMINATE("http://www.w3.org/2002/03/xkms#Indeterminate");
    private final String value;

    KeyBindingEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static KeyBindingEnum fromValue(String v) {
        for (KeyBindingEnum c: KeyBindingEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-3.5.8-sources.jar: org/apache/cxf/xkms/model/xkms/KeyBindingEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for KeyBindingEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="KeyBindingEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Valid"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Invalid"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Indeterminate"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "KeyBindingEnum")
@XmlEnum
public enum KeyBindingEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Valid")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_VALID("http://www.w3.org/2002/03/xkms#Valid"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Invalid")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INVALID("http://www.w3.org/2002/03/xkms#Invalid"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Indeterminate")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INDETERMINATE("http://www.w3.org/2002/03/xkms#Indeterminate");
    private final String value;

    KeyBindingEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static KeyBindingEnum fromValue(String v) {
        for (KeyBindingEnum c: KeyBindingEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
